RESET = "\u001B[0m"

BLACK = "\u001B[30m"
RED = "\u001B[31m"
GREEN = "\u001B[32m"
YELLOW = "\u001B[33m"
BLUE = "\u001B[34m"
PURPLE = "\u001B[35m"
CYAN = "\u001B[36m"
WHITE = "\u001B[37m"

BLACK_BG = "\u001B[40m"
RED_BG = "\u001B[41m"
GREEN_BG = "\u001B[42m"
YELLOW_BG = "\u001B[43m"
BLUE_BG = "\u001B[44m"
PURPLE_BG = "\u001B[45m"
CYAN_BG = "\u001B[46m"
WHITE_BG = "\u001B[47m"


def pprint(text: str, color: str) -> None:
    """Function that prints the text in the given color."""
    print(color + str(text) + RESET)